@@ -1,5 +1,5 @@
 
-kmeans.centers.update=function(out,group,dfunc=func.trim.mode,draw=TRUE,par.dfunc=list(trim=0),...){
+kmeans.centers.update=function(out,group,dfunc=func.trim.FM,draw=TRUE,par.dfunc=list(trim=0.05),...){
 if (class(out)!="kmeans.fd") stop("Error: incorrect input data")
 z=out$fdataobj[["data"]]
 tt=out$fdataobj[["argvals"]]
